@@ -15,10 +15,10 @@ def try_reraise(dec_data: DecData):
 
     if dec_data.exclude:
         if isinstance(func_exception, exception_classes):
-            raise
+            raise dec_data.func_info.exception
     else:
         if not isinstance(func_exception, exception_classes):
-            raise
+            raise dec_data.func_info.exception
 
 
 def check_handler(handler: Callable[[FuncInfo], Any]):
@@ -39,7 +39,7 @@ def check_handler(handler: Callable[[FuncInfo], Any]):
         raise ExDecException(msg)
 
 
-def check_exception(exception: Exception):
+def check_exception_class(exception: Exception):
 
     if not type(exception) is type or not issubclass(exception, Exception):
         msg = "The positional arguments of the 'cath' decorator must "
